Config

Struct Config 

pub struct Config {
Show 13 fields pub network: Network, pub offline: bool, pub fast_sync: bool, pub fixed_difficulty: u128, pub target_max_memory: DefaultOrCustom<u64>, pub tracing: TracingConfig, pub tokio: TokioConfig, pub rayon: RayonConfig, pub p2p: P2PConfig, pub tor: TorConfig, pub rpc: RpcConfig, pub storage: StorageConfig, pub fs: FileSystemConfig,
}
The config for all of Cuprate.

Fields

network: Network

The network cuprated should run on.

Valid values | “Mainnet”, “Testnet”, “Stagenet”, “FakeChain”

offline: bool

Run the node offline.

No connections will be made to or accepted from peers, on any network zone.

Type | boolean Valid values | true, false

fast_sync: bool

Enable/disable fast sync.

Fast sync skips verification of old blocks by comparing block hashes to a built-in hash file, disabling this will significantly increase sync time. New blocks are still fully validated.

Type | boolean Valid values | true, false

fixed_difficulty: u128

Fixes the PoW difficulty to this value.

Only intended for regtest (network = "FakeChain"). A value of 0 disables this override.

Type | Number Valid values | >= 0

target_max_memory: DefaultOrCustom<u64>

The target maximum amount of memory to use in bytes.

This is not a hard limit, but Cuprate will attempt to stay under this value. You probably do not need to change this unless Cuprate can’t read the amount of RAM your system has.

Type | Number Valid values | > 0 Examples | 500_000_000, 1_000_000_000,

tracing: TracingConfig

Configuration for cuprated’s logging system, tracing.

Tracing is used for logging to stdout and files.

tokio: TokioConfig

Configuration for cuprated’s asynchronous runtime system, tokio.

Tokio is used for network operations and the major services inside cuprated.

rayon: RayonConfig

Configuration for cuprated’s thread-pool system, rayon.

Rayon is used for CPU intensive tasks.

p2p: P2PConfig

Configuration for cuprated’s P2P system.

tor: TorConfig

Configuration for cuprated’s Tor component

rpc: RpcConfig

Configuration for cuprated’s RPC system.

storage: StorageConfig

Configuration for persistent data storage.

fs: FileSystemConfig

Configuration for the file-system.

Implementations

Source

impl Config

pub fn write_docs(doc: &mut dyn TableLike)

Source

impl Config

pub fn documented_config() -> String

Returns a default Config, with doc comments.

pub fn read_from_path(file: impl AsRef<Path>) -> Result<Self, Error>

Attempts to read a config file in [toml] format from the given Path.

Errors

Will return an Err if the file cannot be read or if the file is not a valid [toml] config.

pub const fn network(&self) -> Network

Returns the current Network we are running on.

pub fn fast_sync_hashes(&self) -> &'static [[u8; 32]]

Returns the fast-sync validation hashes for this config’s network, or &[] if fast sync is disabled.

pub fn clearnet_p2p_config(&self) -> P2PConfig<ClearNet>

pub fn tor_p2p_config(&self, ctx: &TorContext) -> P2PConfig<Tor>

pub const fn context_config(&self) -> ContextConfig

pub fn blockchain_config(&self) -> Config

The cuprate_blockchain config.

pub fn fjall_directory(&self) -> PathBuf

The directory for fjall.

pub fn fjall_cache_size(&self) -> u64

Returns the size of the fjall cache.

Panics

Panics if target_max_memory is unresolved.

pub fn target_max_memory(&self) -> u64

Returns the target maximum memory usage.

Panics

Panics if target_max_memory is unresolved.

pub fn block_downloader_config(&self) -> BlockDownloaderConfig

The BlockDownloaderConfig.

Panics

Panics if target_max_memory is unresolved.

pub fn dry_run_check(&self) -> Vec<DryRunResult>