pub struct TxpoolConfig {
pub max_txpool_byte_size: usize,
pub maximum_age_secs: u64,
}Expand description
The tx-pool config.
Fields
max_txpool_byte_size: usizeThe maximum size of the tx-pool.
Type | Number Valid values | >= 0 Examples | 100_000_000, 50_000_000
maximum_age_secs: u64The maximum age of transactions in the pool in seconds. Transactions will be dropped after this time is reached.
Type | Number Valid values | >= 0 Examples | 100_000_000, 50_000_000
Implementations
Sourceimpl TxpoolConfig
impl TxpoolConfig
pub fn write_docs(doc: &mut dyn TableLike)