pub struct Config {Show 13 fields
pub network: Network,
pub offline: bool,
pub fast_sync: bool,
pub fixed_difficulty: u128,
pub target_max_memory: DefaultOrCustom<u64>,
pub tracing: TracingConfig,
pub tokio: TokioConfig,
pub rayon: RayonConfig,
pub p2p: P2PConfig,
pub tor: TorConfig,
pub rpc: RpcConfig,
pub storage: StorageConfig,
pub fs: FileSystemConfig,
}Expand description
The config for all of Cuprate.
Fields
network: NetworkThe network cuprated should run on.
Valid values | “Mainnet”, “Testnet”, “Stagenet”, “FakeChain”
offline: boolRun the node offline.
No connections will be made to or accepted from peers, on any network zone.
Type | boolean Valid values | true, false
fast_sync: boolEnable/disable fast sync.
Fast sync skips verification of old blocks by comparing block hashes to a built-in hash file, disabling this will significantly increase sync time. New blocks are still fully validated.
Type | boolean Valid values | true, false
fixed_difficulty: u128Fixes the PoW difficulty to this value.
Only intended for regtest (network = "FakeChain"). A value of
0 disables this override.
Type | Number Valid values | >= 0
target_max_memory: DefaultOrCustom<u64>The target maximum amount of memory to use in bytes.
This is not a hard limit, but Cuprate will attempt to stay under this value. You probably do not need to change this unless Cuprate can’t read the amount of RAM your system has.
Type | Number Valid values | > 0 Examples | 500_000_000, 1_000_000_000,
tracing: TracingConfigConfiguration for cuprated’s logging system, tracing.
Tracing is used for logging to stdout and files.
tokio: TokioConfigConfiguration for cuprated’s asynchronous runtime system, tokio.
Tokio is used for network operations and the major services inside cuprated.
rayon: RayonConfigConfiguration for cuprated’s thread-pool system, rayon.
Rayon is used for CPU intensive tasks.
p2p: P2PConfigConfiguration for cuprated’s P2P system.
tor: TorConfigConfiguration for cuprated’s Tor component
rpc: RpcConfigConfiguration for cuprated’s RPC system.
storage: StorageConfigConfiguration for persistent data storage.
fs: FileSystemConfigConfiguration for the file-system.
Implementations
Sourceimpl Config
impl Config
pub fn write_docs(doc: &mut dyn TableLike)
Sourceimpl Config
impl Config
Sourcepub fn documented_config() -> String
pub fn documented_config() -> String
Returns a default Config, with doc comments.
Sourcepub fn fast_sync_hashes(&self) -> &'static [[u8; 32]]
pub fn fast_sync_hashes(&self) -> &'static [[u8; 32]]
Returns the fast-sync validation hashes for this config’s network,
or &[] if fast sync is disabled.
Sourcepub fn clearnet_p2p_config(&self) -> P2PConfig<ClearNet>
pub fn clearnet_p2p_config(&self) -> P2PConfig<ClearNet>
Sourcepub fn tor_p2p_config(&self, ctx: &TorContext) -> P2PConfig<Tor>
pub fn tor_p2p_config(&self, ctx: &TorContext) -> P2PConfig<Tor>
The Tor, cuprate_p2p::P2PConfig.
Sourcepub const fn context_config(&self) -> ContextConfig
pub const fn context_config(&self) -> ContextConfig
The ContextConfig.
Sourcepub fn blockchain_config(&self) -> Config
pub fn blockchain_config(&self) -> Config
The cuprate_blockchain config.
Sourcepub fn fjall_directory(&self) -> PathBuf
pub fn fjall_directory(&self) -> PathBuf
The directory for fjall.
Sourcepub fn fjall_cache_size(&self) -> u64
pub fn fjall_cache_size(&self) -> u64
Sourcepub fn target_max_memory(&self) -> u64
pub fn target_max_memory(&self) -> u64
Sourcepub fn block_downloader_config(&self) -> BlockDownloaderConfig
pub fn block_downloader_config(&self) -> BlockDownloaderConfig
pub fn dry_run_check(&self) -> Vec<DryRunResult>